@@ -78,6 +78,12 @@ class GoogleCloudPilotAPI(abc.ABC):
             self._service_account_email = getattr(
                 self.credentials, "service_account_email", self._service_account_email
             )
+        elif self._service_account_email is None:  # SDK local authentication
+            self._service_account_email = os.environ.get("GCP_SERVICE_ACCOUNT", None)
+            if not self._service_account_email:
+                logger.warning(
+                    "Using local SDK authentication. Set GCP_SERVICE_ACCOUNT or some features might not work."
+                )
         return self._service_account_email
 
     def _get_client_extra_kwargs(self):
@@ -387,12 +393,14 @@ def friendly_http_error(func):
 
 class DiscoveryMixin:
     @friendly_http_error
-    def _execute(self, method: Callable, **kwargs) -> ResourceType:
+    def _execute(self, method: Callable, method_http_headers=None, **kwargs) -> ResourceType:
         call = method(**kwargs)
         if isinstance(call, Response):
             call.raise_for_status()
             return call.json()
-        return method(**kwargs).execute()
+        if method_http_headers:
+            call.headers = (call.headers or {}) | method_http_headers
+        return call.execute()
 
     def _list(
         self,
